@@ -3,6 +3,8 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
+ 'ALIGNOF_LONG': 4,
+ 'ALIGNOF_SIZE_T': 4,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': 'arm-linux-gnueabihf-gcc-ar',
@@ -11,11 +13,11 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECPPFLAGS': '-IObjects -IInclude -IPython',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/arm-linux-gnueabihf/python3.9',
- 'BLDLIBRARY': '-lpython3.9',
+ 'BINLIBDEST': '/usr/lib/arm-linux-gnueabihf/python3.10',
+ 'BLDLIBRARY': '-lpython3.10',
  'BLDSHARED': 'arm-linux-gnueabihf-gcc -shared -Wl,-O1 '
               '-Wl,-Bsymbolic-functions -Wl,-Bsymbolic-functions '
-              ' -Wl,-z,relro -g '
+              '  -g '
               '-fwrapv -O2   ',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
@@ -40,11 +42,12 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
+                            '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-Wdate-time -D_FORTIFY_SOURCE=2',
  'CONFIGURE_LDFLAGS': '-Wl,-Bsymbolic-functions '
-                      ' -Wl,-z,relro '
+                      '  '
                       '-g -fwrapv -O2   '
                       '',
  'CONFIGURE_LDFLAGS_NODIST': '',
@@ -53,31 +56,33 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--enable-loadable-sqlite-extensions' "
                 "'--with-dbmliborder=bdb:gdbm' '--with-computed-gotos' "
                 "'--without-ensurepip' '--with-system-expat' '--with-dtrace' "
-                "'--with-system-libmpdec' 'MKDIR_P=/bin/mkdir -p' "
-                "'--with-system-ffi' 'CC=arm-linux-gnueabihf-gcc' 'CFLAGS=-g "
+                "'--with-system-libmpdec' "
+                "'--with-wheel-pkg-dir=/usr/share/python-wheels/' "
+                "'MKDIR_P=/bin/mkdir -p' '--with-system-ffi' "
+                "'CC=arm-linux-gnueabihf-gcc' 'CFLAGS=-g "
                 ' '
                 ' -fstack-protector-strong '
                 "-Wformat -Werror=format-security ' "
                 "'LDFLAGS=-Wl,-Bsymbolic-functions "
-                ' -Wl,-z,relro -g '
+                '  -g '
                 "-fwrapv -O2   ' "
                 "'CPPFLAGS=-Wdate-time -D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.9',
+ 'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python3.9-H5nhUU/python3.9-3.9.7/build-shared/coverage.info',
- 'COVERAGE_REPORT': '/build/python3.9-H5nhUU/python3.9-3.9.7/build-shared/lcov-report',
+ 'COVERAGE_INFO': '/build/python3.10-voVA7O/python3.10-3.10.12/build-shared/coverage.info',
+ 'COVERAGE_REPORT': '/build/python3.10-voVA7O/python3.10-3.10.12/build-shared/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
              '-D_FORTIFY_SOURCE=2',
  'CXX': 'arm-linux-gnueabihf-g++',
  'DESTDIRS': '/usr /usr/lib/arm-linux-gnueabihf '
-             '/usr/lib/arm-linux-gnueabihf/python3.9 '
-             '/usr/lib/python3.9/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.9',
+             '/usr/lib/arm-linux-gnueabihf/python3.10 '
+             '/usr/lib/python3.10/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.10',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.9/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.10/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -99,10 +104,11 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPERIMENTAL_ISOLATED_SUBINTERPRETERS': 0,
  'EXPORTSFROM': '',
  'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
- 'EXT_SUFFIX': '.cpython-39-arm-linux-gnueabihf.so',
+ 'EXT_SUFFIX': '.cpython-310-arm-linux-gnueabihf.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
@@ -140,6 +146,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CLOCK_GETRES': 1,
  'HAVE_CLOCK_GETTIME': 1,
  'HAVE_CLOCK_SETTIME': 1,
+ 'HAVE_CLOSE_RANGE': 1,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
@@ -192,6 +199,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
+ 'HAVE_EVENTFD': 1,
  'HAVE_EXECV': 1,
  'HAVE_EXPLICIT_BZERO': 1,
  'HAVE_EXPLICIT_MEMSET': 0,
@@ -293,8 +301,10 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
+ 'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_AUXVEC_H': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
  'HAVE_LINUX_CAN_J1939_H': 1,
@@ -318,7 +328,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
  'HAVE_MEMFD_CREATE': 1,
- 'HAVE_MEMORY_H': 1,
+ 'HAVE_MEMORY_H': 0,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
  'HAVE_MKFIFO': 1,
@@ -384,6 +394,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SCHED_SETAFFINITY': 1,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
+ 'HAVE_SEM_CLOCKWAIT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -426,6 +437,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SOCKADDR_STORAGE': 1,
  'HAVE_SOCKETPAIR': 1,
  'HAVE_SPAWN_H': 1,
+ 'HAVE_SPLICE': 1,
  'HAVE_SSIZE_T': 1,
  'HAVE_STATVFS': 1,
  'HAVE_STAT_TV_NSEC': 1,
@@ -434,7 +446,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
  'HAVE_STD_ATOMIC': 1,
- 'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
@@ -456,11 +467,13 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
+ 'HAVE_SYS_AUXV_H': 1,
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
  'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 1,
+ 'HAVE_SYS_EVENTFD_H': 1,
  'HAVE_SYS_EVENT_H': 0,
  'HAVE_SYS_FILE_H': 1,
  'HAVE_SYS_IOCTL_H': 1,
@@ -521,6 +534,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UUID_GENERATE_TIME_SAFE': 1,
  'HAVE_UUID_H': 0,
  'HAVE_UUID_UUID_H': 1,
+ 'HAVE_VFORK': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -532,50 +546,50 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
- 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'armv7l-unknown-linux-gnueabihf',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.9 '
-                   '/usr/include/python3.9',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.10 '
+                   '/usr/include/python3.10',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.9',
+ 'INCLUDEPY': '/usr/include/python3.10',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.9.so.1.0',
+ 'INSTSONAME': 'libpython3.10.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'arm-linux-gnueabihf-g++ -shared -Wl,-O1 '
                 '-Wl,-Bsymbolic-functions',
  'LDFLAGS': '-Wl,-Bsymbolic-functions  '
-            '-Wl,-z,relro -g -fwrapv -O2   '
+            ' -g -fwrapv -O2   '
             '',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.9.so',
+ 'LDLIBRARY': 'libpython3.10.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'arm-linux-gnueabihf-gcc -shared -Wl,-O1 -Wl,-Bsymbolic-functions '
              '-Wl,-Bsymbolic-functions '
-             ' -Wl,-z,relro -g -fwrapv '
+             '  -g -fwrapv '
              '-O2   ',
- 'LDVERSION': '3.9',
+ 'LDVERSION': '3.10',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.9',
+ 'LIBDEST': '/usr/lib/python3.10',
  'LIBDIR': '/usr/lib/arm-linux-gnueabihf',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/arm-linux-gnueabihf/pkgconfig',
- 'LIBPL': '/usr/lib/python3.9/config-3.9-arm-linux-gnueabihf',
+ 'LIBPL': '/usr/lib/python3.10/config-3.10-arm-linux-gnueabihf',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.9.a',
+ 'LIBRARY': 'libpython3.10.a',
+ 'LIBRARY_DEPS': 'libpython3.10.a libpython3.10.so libpython3.so',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lcrypt -ldl  -lm',
- 'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
+ 'LIBSUBDIRS': 'asyncio \\',
  'LINKCC': 'arm-linux-gnueabihf-gcc',
  'LINKFORSHARED': '-Xlinker -export-dynamic -Wl,-O1 -Wl,-Bsymbolic-functions',
  'LIPO_32BIT_FLAGS': '',
@@ -585,10 +599,10 @@ build_time_vars = {'ABIFLAGS': '',
  'LLVM_PROF_MERGER': 'true',
  'LN': 'ln',
  'LOCALMODLIBS': '-lexpat                       -L/usr/lib '
-                 '-lz                        -lexpat',
+                 '-lz                       -lexpat',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/arm-linux-gnueabihf/python3.9',
+ 'MACHDESTLIB': '/usr/lib/arm-linux-gnueabihf/python3.10',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'arm-linux-gnueabihf-gcc',
  'MAJOR_IN_MKDEV': 0,
@@ -603,11 +617,11 @@ build_time_vars = {'ABIFLAGS': '',
                    '_blake2  syslog  binascii  zlib  posix  errno  pwd  _sre  '
                    '_codecs  _weakref  _functools  _operator  _collections  '
                    '_abc  itertools  atexit  _signal  _stat  time  _thread  '
-                   '_locale  _io  faulthandler  _tracemalloc  _peg_parser  '
-                   '_symtable  pyexpat  xxsubtype',
+                   '_locale  _io  faulthandler  _tracemalloc  _symtable  '
+                   'pyexpat  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '-lexpat                       -L/usr/lib '
-            '-lz                        -lexpat',
+            '-lz                       -lexpat',
  'MODOBJS': '$(sort   Modules/arraymodule.o  Modules/cmathmodule.o '
             'Modules/_math.o  Modules/mathmodule.o Modules/_math.o  '
             'Modules/_struct.o  Modules/_randommodule.o  '
@@ -633,8 +647,8 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
             'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
             'Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
-            'Modules/symtablemodule.o  Modules/pyexpat.o  Modules/xxsubtype.o)',
+            'Modules/_tracemalloc.o  Modules/symtablemodule.o  '
+            'Modules/pyexpat.o  Modules/xxsubtype.o)',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'arm-linux-gnueabihf',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"arm-linux-gnueabihf\\"',
@@ -644,6 +658,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
+ 'OPENSSL_RPATH': '',
  'OPT': '-DNDEBUG -g -fwrapv -O2 -Wall',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -653,8 +668,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
-                'Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/tokenizer.o',
  'PEGEN_HEADERS': '\\',
  'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
@@ -662,7 +676,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo',
+ 'PROFILE_TASK': '-m test --pgo --timeout=1200',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -675,6 +689,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
@@ -687,18 +702,21 @@ build_time_vars = {'ABIFLAGS': '',
                              '  -std=c99 '
                              '-Wextra -Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
+                             '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I../Include/internal '
                              '-IObjects -IInclude -IPython -I. -I../Include '
                              '-Wdate-time -D_FORTIFY_SOURCE=2 -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O2 -Wall '
-              '-g  '
+              '-g '
+              ' '
               ' -fstack-protector-strong '
               '-Wformat -Werror=format-security  -g -fwrapv -O2  '
               ' ',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I../Include/internal',
  'PY_COERCE_C_LOCALE': 1,
@@ -709,19 +727,20 @@ build_time_vars = {'ABIFLAGS': '',
                    '-fstack-protector-strong -Wformat -Werror=format-security  -g '
                    '-fwrapv -O2    '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I../Include/internal -IObjects -IInclude -IPython -I. '
                    '-I../Include -Wdate-time -D_FORTIFY_SOURCE=2 -fPIC '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-Bsymbolic-functions '
-                    ' -Wl,-z,relro -g '
+                    '  -g '
                     '-fwrapv -O2   ',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Include -Wdate-time '
                 '-D_FORTIFY_SOURCE=2',
+ 'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-Bsymbolic-functions '
-               ' -Wl,-z,relro -g '
+               '  -g '
                '-fwrapv -O2   ',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
@@ -734,6 +753,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '-g -fwrapv -O2   '
                         ' -std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I../Include/internal -IObjects '
                         '-IInclude -IPython -I. -I../Include -Wdate-time '
@@ -746,10 +766,9 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.9-H5nhUU/python3.9-3.9.7/build-shared',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python3.10-voVA7O/python3.10-3.10.12/build-shared',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
- 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
  'SHLIBS': '-lcrypt -ldl  -lm',
  'SHLIB_SUFFIX': '.so',
@@ -774,9 +793,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-39-arm-linux-gnueabihf',
- 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-310-arm-linux-gnueabihf',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': '../Tools/gdb/libpython.py',
+ 'STATIC_LIBPYTHON': 1,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -784,39 +804,44 @@ build_time_vars = {'ABIFLAGS': '',
  'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
- 'TCLTK_INCLUDES': '',
- 'TCLTK_LIBS': '',
+ 'TCLTK_INCLUDES': '-I/usr/include/tcl8.6',
+ 'TCLTK_LIBS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.9-H5nhUU/python3.9-3.9.7/build-shared '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python3.10-voVA7O/python3.10-3.10.12/build-shared '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.9-H5nhUU/python3.9-3.9.7/build-shared '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python3.10-voVA7O/python3.10-3.10.12/build-shared '
                './python ../Tools/scripts/run_tests.py',
+ 'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
+ 'TEST_MODULES': 'yes',
+ 'THREAD_STACK_SIZE': 0,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3.9 ../Tools/scripts/update_file.py',
+ 'UPDATE_FILE': '../Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'VERSION': '3.9',
+ 'VERSION': '3.10',
  'VPATH': '..',
+ 'WHEEL_PKG_DIR': '/usr/share/python-wheels/',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 1,
  'WITH_DYLD': 0,
+ 'WITH_EDITLINE': 0,
  'WITH_LIBINTL': 0,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python3.9-H5nhUU/python3.9-3.9.7/build-shared',
- 'abs_srcdir': '/build/python3.9-H5nhUU/python3.9-3.9.7/build-shared/..',
+ 'abs_builddir': '/build/python3.10-voVA7O/python3.10-3.10.12/build-shared',
+ 'abs_srcdir': '/build/python3.10-voVA7O/python3.10-3.10.12/build-shared/..',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
