@@ -10,49 +10,53 @@ Do NOT use this module directly - use reactor.spawnProcess() instead.
 Maintainer: Itamar Shtull-Trauring
 """
 
-from __future__ import division, absolute_import, print_function
-
-from twisted.python.runtime import platform
-
-if platform.isWindows():
-    raise ImportError(("twisted.internet.process does not work on Windows. "
-                       "Use the reactor.spawnProcess() API instead."))
-
 import errno
 import gc
-import os
 import io
-import select
+import os
 import signal
 import stat
 import sys
 import traceback
-
-try:
-    import pty
-except ImportError:
-    pty = None
-
-try:
-    import fcntl, termios
-except ImportError:
-    fcntl = None
+from typing import Callable, Dict, Optional
 
 from zope.interface import implementer
 
-from twisted.python import log, failure
-from twisted.python.util import switchUID
-from twisted.python.compat import items, range, _PY3
-from twisted.internet import fdesc, abstract, error
-from twisted.internet.main import CONNECTION_LOST, CONNECTION_DONE
+from twisted.internet import abstract, error, fdesc
 from twisted.internet._baseprocess import BaseProcess
 from twisted.internet.interfaces import IProcessTransport
+from twisted.internet.main import CONNECTION_DONE, CONNECTION_LOST
+from twisted.python import failure, log
+from twisted.python.runtime import platform
+from twisted.python.util import switchUID
+
+if platform.isWindows():
+    raise ImportError(
+        "twisted.internet.process does not work on Windows. "
+        "Use the reactor.spawnProcess() API instead."
+    )
+
+try:
+    import pty as _pty
+except ImportError:
+    pty = None
+else:
+    pty = _pty
+
+try:
+    import fcntl as _fcntl
+    import termios
+except ImportError:
+    fcntl = None
+else:
+    fcntl = _fcntl
 
 # Some people were importing this, which is incorrect, just keeping it
 # here for backwards compatibility:
 ProcessExitedAlready = error.ProcessExitedAlready
 
-reapProcessHandlers = {}
+reapProcessHandlers: Dict[int, Callable] = {}
+
 
 def reapAllProcesses():
     """
@@ -64,7 +68,6 @@ def reapAllProcesses():
         process.reapProcess()
 
 
-
 def registerReapProcessHandler(pid, process):
     """
     Register a process handler for the given pid, in case L{reapAllProcesses}
@@ -77,9 +80,13 @@ def registerReapProcessHandler(pid, process):
         raise RuntimeError("Try to register an already registered process.")
     try:
         auxPID, status = os.waitpid(pid, os.WNOHANG)
-    except:
-        log.msg('Failed to reap %d:' % pid)
+    except BaseException:
+        log.msg(f"Failed to reap {pid}:")
         log.err()
+
+        if pid is None:
+            return
+
         auxPID = None
     if auxPID:
         process.processEnded(status)
@@ -88,47 +95,16 @@ def registerReapProcessHandler(pid, process):
         reapProcessHandlers[pid] = process
 
 
-
 def unregisterReapProcessHandler(pid, process):
     """
     Unregister a process handler previously registered with
     L{registerReapProcessHandler}.
     """
-    if not (pid in reapProcessHandlers
-            and reapProcessHandlers[pid] == process):
+    if not (pid in reapProcessHandlers and reapProcessHandlers[pid] == process):
         raise RuntimeError("Try to unregister a process not registered.")
     del reapProcessHandlers[pid]
 
 
-
-def detectLinuxBrokenPipeBehavior():
-    """
-    On some Linux version, write-only pipe are detected as readable. This
-    function is here to check if this bug is present or not.
-
-    See L{ProcessWriter.doRead} for a more detailed explanation.
-
-    @return: C{True} if Linux pipe behaviour is broken.
-    @rtype : L{bool}
-    """
-    r, w = os.pipe()
-    os.write(w, b'a')
-    reads, writes, exes = select.select([w], [], [], 0)
-    if reads:
-        # Linux < 2.6.11 says a write-only pipe is readable.
-        brokenPipeBehavior = True
-    else:
-        brokenPipeBehavior = False
-    os.close(r)
-    os.close(w)
-    return brokenPipeBehavior
-
-
-
-brokenLinuxPipeBehavior = detectLinuxBrokenPipeBehavior()
-
-
-
 class ProcessWriter(abstract.FileDescriptor):
     """
     (Internal) Helper class to write into a Process's input pipe.
@@ -142,6 +118,7 @@ class ProcessWriter(abstract.FileDescriptor):
         the connection has been lost).  If C{False}, then readability events
         are ignored.
     """
+
     connected = 1
     ic = 0
     enableReadHack = False
@@ -177,14 +154,12 @@ class ProcessWriter(abstract.FileDescriptor):
         if self.enableReadHack:
             self.startReading()
 
-
     def fileno(self):
         """
         Return the fileno() of my process's stdin.
         """
         return self.fd
 
-
     def writeSomeData(self, data):
         """
         Write some data to the open process.
@@ -197,12 +172,10 @@ class ProcessWriter(abstract.FileDescriptor):
             self.startReading()
         return rv
 
-
     def write(self, data):
         self.stopReading()
         abstract.FileDescriptor.write(self, data)
 
-
     def doRead(self):
         """
         The only way a write pipe can become "readable" is at EOF, because the
@@ -217,23 +190,12 @@ class ProcessWriter(abstract.FileDescriptor):
 
         That's what this funky code is for. If linux was not broken, this
         function could be simply "return CONNECTION_LOST".
-
-        BUG: We call select no matter what the reactor.
-        If the reactor is pollreactor, and the fd is > 1024, this will fail.
-        (only occurs on broken versions of linux, though).
         """
         if self.enableReadHack:
-            if brokenLinuxPipeBehavior:
-                fd = self.fd
-                r, w, x = select.select([fd], [fd], [], 0)
-                if r and w:
-                    return CONNECTION_LOST
-            else:
-                return CONNECTION_LOST
+            return CONNECTION_LOST
         else:
             self.stopReading()
 
-
     def connectionLost(self, reason):
         """
         See abstract.FileDescriptor.connectionLost.
@@ -247,7 +209,6 @@ class ProcessWriter(abstract.FileDescriptor):
         self.proc.childConnectionLost(self.name, reason)
 
 
-
 class ProcessReader(abstract.FileDescriptor):
     """
     ProcessReader
@@ -255,6 +216,7 @@ class ProcessReader(abstract.FileDescriptor):
     I am a selectable representation of a process's output pipe, such as
     stdout and stderr.
     """
+
     connected = True
 
     def __init__(self, reactor, proc, name, fileno):
@@ -268,14 +230,12 @@ class ProcessReader(abstract.FileDescriptor):
         self.fd = fileno
         self.startReading()
 
-
     def fileno(self):
         """
         Return the fileno() of my process's stderr.
         """
         return self.fd
 
-
     def writeSomeData(self, data):
         # the only time this is actually called is after .loseConnection Any
         # actual write attempt would fail, so we must avoid that. This hack
@@ -283,25 +243,22 @@ class ProcessReader(abstract.FileDescriptor):
         assert data == b""
         return CONNECTION_LOST
 
-
     def doRead(self):
         """
         This is called when the pipe becomes readable.
         """
         return fdesc.readFromFD(self.fd, self.dataReceived)
 
-
     def dataReceived(self, data):
         self.proc.childDataReceived(self.name, data)
 
-
     def loseConnection(self):
         if self.connected and not self.disconnecting:
             self.disconnecting = 1
             self.stopReading()
-            self.reactor.callLater(0, self.connectionLost,
-                                   failure.Failure(CONNECTION_DONE))
-
+            self.reactor.callLater(
+                0, self.connectionLost, failure.Failure(CONNECTION_DONE)
+            )
 
     def connectionLost(self, reason):
         """
@@ -312,12 +269,12 @@ class ProcessReader(abstract.FileDescriptor):
         self.proc.childConnectionLost(self.name, reason)
 
 
-
-class _BaseProcess(BaseProcess, object):
+class _BaseProcess(BaseProcess):
     """
     Base class for Process and PTYProcess.
     """
-    status = None
+
+    status: Optional[int] = None
     pid = None
 
     def reapProcess(self):
@@ -342,14 +299,13 @@ class _BaseProcess(BaseProcess, object):
                     pid = None
                 else:
                     raise
-        except:
-            log.msg('Failed to reap %d:' % self.pid)
+        except BaseException:
+            log.msg(f"Failed to reap {self.pid}:")
             log.err()
             pid = None
         if pid:
-            self.processEnded(status)
             unregisterReapProcessHandler(pid, self)
-
+            self.processEnded(status)
 
     def _getReason(self, status):
         exitCode = sig = None
@@ -361,7 +317,6 @@ class _BaseProcess(BaseProcess, object):
             return error.ProcessTerminated(exitCode, sig, status)
         return error.ProcessDone(status)
 
-
     def signalProcess(self, signalID):
         """
         Send the given signal C{signalID} to the process. It'll translate a
@@ -371,8 +326,8 @@ class _BaseProcess(BaseProcess, object):
 
         @type signalID: C{str} or C{int}
         """
-        if signalID in ('HUP', 'STOP', 'INT', 'KILL', 'TERM'):
-            signalID = getattr(signal, 'SIG%s' % (signalID,))
+        if signalID in ("HUP", "STOP", "INT", "KILL", "TERM"):
+            signalID = getattr(signal, f"SIG{signalID}")
         if self.pid is None:
             raise ProcessExitedAlready()
         try:
@@ -383,7 +338,6 @@ class _BaseProcess(BaseProcess, object):
             else:
                 raise
 
-
     def _resetSignalDisposition(self):
         # The Python interpreter ignores some signals, and our child
         # process will inherit that behaviour. To have a child process
@@ -395,7 +349,6 @@ class _BaseProcess(BaseProcess, object):
                 # Reset signal handling to the default
                 signal.signal(signalnum, signal.SIG_DFL)
 
-
     def _fork(self, path, uid, gid, executable, args, environment, **kwargs):
         """
         Fork and then exec sub-process.
@@ -418,7 +371,7 @@ class _BaseProcess(BaseProcess, object):
         gc.disable()
         try:
             self.pid = os.fork()
-        except:
+        except BaseException:
             # Still in the parent process
             if collectorEnabled:
                 gc.enable()
@@ -441,9 +394,8 @@ class _BaseProcess(BaseProcess, object):
                     # Stop debugging. If I am, I don't care anymore.
                     sys.settrace(None)
                     self._setupChild(**kwargs)
-                    self._execChild(path, uid, gid, executable, args,
-                                    environment)
-                except:
+                    self._execChild(path, uid, gid, executable, args, environment)
+                except BaseException:
                     # If there are errors, try to write something descriptive
                     # to stderr before exiting.
 
@@ -452,38 +404,33 @@ class _BaseProcess(BaseProcess, object):
                     # write(2, err) is a useful thing to attempt.
 
                     try:
-                        stderr = os.fdopen(2, 'wb')
-                        msg = ("Upon execvpe {0} {1} in environment id {2}"
-                               "\n:").format(executable, str(args),
-                                             id(environment))
+                        # On Python 3, print_exc takes a text stream, but
+                        # on Python 2 it still takes a byte stream.  So on
+                        # Python 3 we will wrap up the byte stream returned
+                        # by os.fdopen using TextIOWrapper.
 
-                        if _PY3:
-
-                            # On Python 3, print_exc takes a text stream, but
-                            # on Python 2 it still takes a byte stream.  So on
-                            # Python 3 we will wrap up the byte stream returned
-                            # by os.fdopen using TextIOWrapper.
-
-                            # We hard-code UTF-8 as the encoding here, rather
-                            # than looking at something like
-                            # getfilesystemencoding() or sys.stderr.encoding,
-                            # because we want an encoding that will be able to
-                            # encode the full range of code points.  We are
-                            # (most likely) talking to the parent process on
-                            # the other end of this pipe and not the filesystem
-                            # or the original sys.stderr, so there's no point
-                            # in trying to match the encoding of one of those
-                            # objects.
-
-                            stderr = io.TextIOWrapper(stderr, encoding="utf-8")
+                        # We hard-code UTF-8 as the encoding here, rather
+                        # than looking at something like
+                        # getfilesystemencoding() or sys.stderr.encoding,
+                        # because we want an encoding that will be able to
+                        # encode the full range of code points.  We are
+                        # (most likely) talking to the parent process on
+                        # the other end of this pipe and not the filesystem
+                        # or the original sys.stderr, so there's no point
+                        # in trying to match the encoding of one of those
+                        # objects.
 
+                        stderr = io.TextIOWrapper(os.fdopen(2, "wb"), encoding="utf-8")
+                        msg = ("Upon execvpe {} {} in environment id {}" "\n:").format(
+                            executable, str(args), id(environment)
+                        )
                         stderr.write(msg)
                         traceback.print_exc(file=stderr)
                         stderr.flush()
 
                         for fd in range(3):
                             os.close(fd)
-                    except:
+                    except BaseException:
                         # Handle all errors during the error-reporting process
                         # silently to ensure that the child terminates.
                         pass
@@ -495,8 +442,7 @@ class _BaseProcess(BaseProcess, object):
         # we are now in parent process
         if collectorEnabled:
             gc.enable()
-        self.status = -1 # this records the exit status of the child
-
+        self.status = -1  # this records the exit status of the child
 
     def _setupChild(self, *args, **kwargs):
         """
@@ -504,7 +450,6 @@ class _BaseProcess(BaseProcess, object):
         """
         raise NotImplementedError()
 
-
     def _execChild(self, path, uid, gid, executable, args, environment):
         """
         The exec() which is done in the forked child.
@@ -522,17 +467,18 @@ class _BaseProcess(BaseProcess, object):
             switchUID(uid, gid)
         os.execvpe(executable, args, environment)
 
-
-    def __repr__(self):
+    def __repr__(self) -> str:
         """
         String representation of a process.
         """
-        return "<%s pid=%s status=%s>" % (self.__class__.__name__,
-                                          self.pid, self.status)
+        return "<{} pid={} status={}>".format(
+            self.__class__.__name__,
+            self.pid,
+            self.status,
+        )
 
 
-
-class _FDDetector(object):
+class _FDDetector:
     """
     This class contains the logic necessary to decide which of the available
     system techniques should be used to detect the open file descriptors for
@@ -547,6 +493,7 @@ class _FDDetector(object):
     @ivar openfile: The implementation of open() to use, by default the Python
         builtin.
     """
+
     # So that we can unit test this
     listdir = os.listdir
     getpid = os.getpid
@@ -554,9 +501,10 @@ class _FDDetector(object):
 
     def __init__(self):
         self._implementations = [
-            self._procFDImplementation, self._devFDImplementation,
-            self._fallbackFDImplementation]
-
+            self._procFDImplementation,
+            self._devFDImplementation,
+            self._fallbackFDImplementation,
+        ]
 
     def _listOpenFDs(self):
         """
@@ -569,7 +517,6 @@ class _FDDetector(object):
         self._listOpenFDs = self._getImplementation()
         return self._listOpenFDs()
 
-
     def _getImplementation(self):
         """
         Pick a method which gives correct results for C{_listOpenFDs} in this
@@ -585,7 +532,7 @@ class _FDDetector(object):
         for impl in self._implementations:
             try:
                 before = impl()
-            except:
+            except BaseException:
                 continue
             with self.openfile("/dev/null", "r"):
                 after = impl()
@@ -599,7 +546,6 @@ class _FDDetector(object):
         # by _fallbackFDImplementation is suitable to be the last entry.
         return impl
 
-
     def _devFDImplementation(self):
         """
         Simple implementation for systems where /dev/fd actually works.
@@ -609,7 +555,6 @@ class _FDDetector(object):
         result = [int(fd) for fd in self.listdir(dname)]
         return result
 
-
     def _procFDImplementation(self):
         """
         Simple implementation for systems where /proc/pid/fd exists (we assume
@@ -618,7 +563,6 @@ class _FDDetector(object):
         dname = "/proc/%d/fd" % (self.getpid(),)
         return [int(fd) for fd in self.listdir(dname)]
 
-
     def _fallbackFDImplementation(self):
         """
         Fallback implementation where either the resource module can inform us
@@ -640,9 +584,9 @@ class _FDDetector(object):
         return range(maxfds)
 
 
-
 detector = _FDDetector()
 
+
 def _listOpenFDs():
     """
     Use the global detector object to figure out which FD implementation to
@@ -651,7 +595,6 @@ def _listOpenFDs():
     return detector._listOpenFDs()
 
 
-
 @implementer(IProcessTransport)
 class Process(_BaseProcess):
     """
@@ -666,6 +609,7 @@ class Process(_BaseProcess):
     code is not cross-platform. (also, windows can only select
     on sockets...)
     """
+
     debug = False
     debug_child = False
 
@@ -675,9 +619,18 @@ class Process(_BaseProcess):
     processWriterFactory = ProcessWriter
     processReaderFactory = ProcessReader
 
-    def __init__(self,
-                 reactor, executable, args, environment, path, proto,
-                 uid=None, gid=None, childFDs=None):
+    def __init__(
+        self,
+        reactor,
+        executable,
+        args,
+        environment,
+        path,
+        proto,
+        uid=None,
+        gid=None,
+        childFDs=None,
+    ):
         """
         Spawn an operating-system process.
 
@@ -691,8 +644,8 @@ class Process(_BaseProcess):
         or real UID is 0.)
         """
         if not proto:
-            assert 'r' not in childFDs.values()
-            assert 'w' not in childFDs.values()
+            assert "r" not in childFDs.values()
+            assert "w" not in childFDs.values()
         _BaseProcess.__init__(self, proto)
 
         self.pipes = {}
@@ -704,46 +657,54 @@ class Process(_BaseProcess):
         # values are parentFDs
 
         if childFDs is None:
-            childFDs = {0: "w", # we write to the child's stdin
-                        1: "r", # we read from their stdout
-                        2: "r", # and we read from their stderr
-                        }
+            childFDs = {
+                0: "w",  # we write to the child's stdin
+                1: "r",  # we read from their stdout
+                2: "r",  # and we read from their stderr
+            }
 
         debug = self.debug
-        if debug: print("childFDs", childFDs)
+        if debug:
+            print("childFDs", childFDs)
 
         _openedPipes = []
+
         def pipe():
             r, w = os.pipe()
             _openedPipes.extend([r, w])
             return r, w
 
         # fdmap.keys() are filenos of pipes that are used by the child.
-        fdmap = {} # maps childFD to parentFD
+        fdmap = {}  # maps childFD to parentFD
         try:
-            for childFD, target in items(childFDs):
-                if debug: print("[%d]" % childFD, target)
+            for childFD, target in childFDs.items():
+                if debug:
+                    print("[%d]" % childFD, target)
                 if target == "r":
                     # we need a pipe that the parent can read from
                     readFD, writeFD = pipe()
-                    if debug: print("readFD=%d, writeFD=%d" % (readFD, writeFD))
-                    fdmap[childFD] = writeFD     # child writes to this
-                    helpers[childFD] = readFD    # parent reads from this
+                    if debug:
+                        print("readFD=%d, writeFD=%d" % (readFD, writeFD))
+                    fdmap[childFD] = writeFD  # child writes to this
+                    helpers[childFD] = readFD  # parent reads from this
                 elif target == "w":
                     # we need a pipe that the parent can write to
                     readFD, writeFD = pipe()
-                    if debug: print("readFD=%d, writeFD=%d" % (readFD, writeFD))
-                    fdmap[childFD] = readFD      # child reads from this
-                    helpers[childFD] = writeFD   # parent writes to this
+                    if debug:
+                        print("readFD=%d, writeFD=%d" % (readFD, writeFD))
+                    fdmap[childFD] = readFD  # child reads from this
+                    helpers[childFD] = writeFD  # parent writes to this
                 else:
-                    assert type(target) == int, '%r should be an int' % (target,)
-                    fdmap[childFD] = target      # parent ignores this
-            if debug: print("fdmap", fdmap)
-            if debug: print("helpers", helpers)
+                    assert type(target) == int, f"{target!r} should be an int"
+                    fdmap[childFD] = target  # parent ignores this
+            if debug:
+                print("fdmap", fdmap)
+            if debug:
+                print("helpers", helpers)
             # the child only cares about fdmap.values()
 
             self._fork(path, uid, gid, executable, args, environment, fdmap=fdmap)
-        except:
+        except BaseException:
             for pipe in _openedPipes:
                 os.close(pipe)
             raise
@@ -752,23 +713,23 @@ class Process(_BaseProcess):
         self.proto = proto
 
         # arrange for the parent-side pipes to be read and written
-        for childFD, parentFD in items(helpers):
+        for childFD, parentFD in helpers.items():
             os.close(fdmap[childFD])
             if childFDs[childFD] == "r":
-                reader = self.processReaderFactory(reactor, self, childFD,
-                                        parentFD)
+                reader = self.processReaderFactory(reactor, self, childFD, parentFD)
                 self.pipes[childFD] = reader
 
             if childFDs[childFD] == "w":
-                writer = self.processWriterFactory(reactor, self, childFD,
-                                        parentFD, forceReadHack=True)
+                writer = self.processWriterFactory(
+                    reactor, self, childFD, parentFD, forceReadHack=True
+                )
                 self.pipes[childFD] = writer
 
         try:
             # the 'transport' is used for some compatibility methods
             if self.proto is not None:
                 self.proto.makeConnection(self)
-        except:
+        except BaseException:
             log.err()
 
         # The reactor might not be running yet.  This might call back into
@@ -777,7 +738,6 @@ class Process(_BaseProcess):
         # spawnProcess should improve upon this situation.
         registerReapProcessHandler(self.pid, self)
 
-
     def _setupChild(self, fdmap):
         """
         fdmap[childFD] = parentFD
@@ -821,34 +781,37 @@ class Process(_BaseProcess):
                 continue
             try:
                 os.close(fd)
-            except:
+            except BaseException:
                 pass
 
         # at this point, the only fds still open are the ones that need to
         # be moved to their appropriate positions in the child (the targets
         # of fdmap, i.e. fdmap.values() )
 
-        if debug: print("fdmap", fdmap, file=errfd)
+        if debug:
+            print("fdmap", fdmap, file=errfd)
         for child in sorted(fdmap.keys()):
             target = fdmap[child]
             if target == child:
                 # fd is already in place
-                if debug: print("%d already in place" % target, file=errfd)
+                if debug:
+                    print("%d already in place" % target, file=errfd)
                 fdesc._unsetCloseOnExec(child)
             else:
                 if child in fdmap.values():
                     # we can't replace child-fd yet, as some other mapping
                     # still needs the fd it wants to target. We must preserve
                     # that old fd by duping it to a new home.
-                    newtarget = os.dup(child) # give it a safe home
-                    if debug: print("os.dup(%d) -> %d" % (child, newtarget),
-                                    file=errfd)
-                    os.close(child) # close the original
-                    for c, p in items(fdmap):
+                    newtarget = os.dup(child)  # give it a safe home
+                    if debug:
+                        print("os.dup(%d) -> %d" % (child, newtarget), file=errfd)
+                    os.close(child)  # close the original
+                    for c, p in list(fdmap.items()):
                         if p == child:
-                            fdmap[c] = newtarget # update all pointers
+                            fdmap[c] = newtarget  # update all pointers
                 # now it should be available
-                if debug: print("os.dup2(%d,%d)" % (target, child), file=errfd)
+                if debug:
+                    print("os.dup2(%d,%d)" % (target, child), file=errfd)
                 os.dup2(target, child)
 
         # At this point, the child has everything it needs. We want to close
@@ -861,20 +824,19 @@ class Process(_BaseProcess):
 
         old = []
         for fd in fdmap.values():
-            if not fd in old:
-                if not fd in fdmap.keys():
+            if fd not in old:
+                if fd not in fdmap.keys():
                     old.append(fd)
-        if debug: print("old", old, file=errfd)
+        if debug:
+            print("old", old, file=errfd)
         for fd in old:
             os.close(fd)
 
         self._resetSignalDisposition()
 
-
     def writeToChild(self, childFD, data):
         self.pipes[childFD].write(data)
 
-
     def closeChildFD(self, childFD):
         # for writer pipes, loseConnection tries to write the remaining data
         # out to the pipe before closing it
@@ -883,15 +845,13 @@ class Process(_BaseProcess):
         if childFD in self.pipes:
             self.pipes[childFD].loseConnection()
 
-
     def pauseProducing(self):
-        for p in self.pipes.itervalues():
+        for p in self.pipes.values():
             if isinstance(p, ProcessReader):
                 p.stopReading()
 
-
     def resumeProducing(self):
-        for p in self.pipes.itervalues():
+        for p in self.pipes.values():
             if isinstance(p, ProcessReader):
                 p.startReading()
 
@@ -902,21 +862,17 @@ class Process(_BaseProcess):
         """
         self.closeChildFD(0)
 
-
     def closeStdout(self):
         self.closeChildFD(1)
 
-
     def closeStderr(self):
         self.closeChildFD(2)
 
-
     def loseConnection(self):
         self.closeStdin()
         self.closeStderr()
         self.closeStdout()
 
-
     def write(self, data):
         """
         Call this to write to standard input on this process.
@@ -926,7 +882,6 @@ class Process(_BaseProcess):
         if 0 in self.pipes:
             self.pipes[0].write(data)
 
-
     def registerProducer(self, producer, streaming):
         """
         Call this to register producer for standard input.
@@ -939,14 +894,12 @@ class Process(_BaseProcess):
         else:
             producer.stopProducing()
 
-
     def unregisterProducer(self):
         """
         Call this to unregister producer for standard input."""
         if 0 in self.pipes:
             self.pipes[0].unregisterProducer()
 
-
     def writeSequence(self, seq):
         """
         Call this to write to standard input on this process.
@@ -956,11 +909,9 @@ class Process(_BaseProcess):
         if 0 in self.pipes:
             self.pipes[0].writeSequence(seq)
 
-
     def childDataReceived(self, name, data):
         self.proto.childDataReceived(name, data)
 
-
     def childConnectionLost(self, childFD, reason):
         # this is called when one of the helpers (ProcessReader or
         # ProcessWriter) notices their pipe has been closed
@@ -968,11 +919,10 @@ class Process(_BaseProcess):
         del self.pipes[childFD]
         try:
             self.proto.childConnectionLost(childFD)
-        except:
+        except BaseException:
             log.err()
         self.maybeCallProcessEnded()
 
-
     def maybeCallProcessEnded(self):
         # we don't call ProcessProtocol.processEnded until:
         #  the child has terminated, AND
@@ -986,6 +936,13 @@ class Process(_BaseProcess):
             return
         _BaseProcess.maybeCallProcessEnded(self)
 
+    def getHost(self):
+        # ITransport.getHost
+        raise NotImplementedError()
+
+    def getPeer(self):
+        # ITransport.getPeer
+        raise NotImplementedError()
 
 
 @implementer(IProcessTransport)
@@ -997,8 +954,18 @@ class PTYProcess(abstract.FileDescriptor, _BaseProcess):
     status = -1
     pid = None
 
-    def __init__(self, reactor, executable, args, environment, path, proto,
-                 uid=None, gid=None, usePTY=None):
+    def __init__(
+        self,
+        reactor,
+        executable,
+        args,
+        environment,
+        path,
+        proto,
+        uid=None,
+        gid=None,
+        usePTY=None,
+    ):
         """
         Spawn an operating-system process.
 
@@ -1014,7 +981,8 @@ class PTYProcess(abstract.FileDescriptor, _BaseProcess):
         if pty is None and not isinstance(usePTY, (tuple, list)):
             # no pty module and we didn't get a pty to use
             raise NotImplementedError(
-                "cannot use PTYProcess on platforms without the pty module.")
+                "cannot use PTYProcess on platforms without the pty module."
+            )
         abstract.FileDescriptor.__init__(self, reactor)
         _BaseProcess.__init__(self, proto)
 
@@ -1024,9 +992,17 @@ class PTYProcess(abstract.FileDescriptor, _BaseProcess):
             masterfd, slavefd = pty.openpty()
 
         try:
-            self._fork(path, uid, gid, executable, args, environment,
-                       masterfd=masterfd, slavefd=slavefd)
-        except:
+            self._fork(
+                path,
+                uid,
+                gid,
+                executable,
+                args,
+                environment,
+                masterfd=masterfd,
+                slavefd=slavefd,
+            )
+        except BaseException:
             if not isinstance(usePTY, (tuple, list)):
                 os.close(masterfd)
                 os.close(slavefd)
@@ -1041,11 +1017,10 @@ class PTYProcess(abstract.FileDescriptor, _BaseProcess):
         self.status = -1
         try:
             self.proto.makeConnection(self)
-        except:
+        except BaseException:
             log.err()
         registerReapProcessHandler(self.pid, self)
 
-
     def _setupChild(self, masterfd, slavefd):
         """
         Set up child process after C{fork()} but before C{exec()}.
@@ -1075,48 +1050,43 @@ class PTYProcess(abstract.FileDescriptor, _BaseProcess):
         """
         os.close(masterfd)
         os.setsid()
-        fcntl.ioctl(slavefd, termios.TIOCSCTTY, '')
+        fcntl.ioctl(slavefd, termios.TIOCSCTTY, "")
 
         for fd in range(3):
             if fd != slavefd:
                 os.close(fd)
 
-        os.dup2(slavefd, 0) # stdin
-        os.dup2(slavefd, 1) # stdout
-        os.dup2(slavefd, 2) # stderr
+        os.dup2(slavefd, 0)  # stdin
+        os.dup2(slavefd, 1)  # stdout
+        os.dup2(slavefd, 2)  # stderr
 
         for fd in _listOpenFDs():
             if fd > 2:
                 try:
                     os.close(fd)
-                except:
+                except BaseException:
                     pass
 
         self._resetSignalDisposition()
 
-
     def closeStdin(self):
         # PTYs do not have stdin/stdout/stderr. They only have in and out, just
         # like sockets. You cannot close one without closing off the entire PTY
         pass
 
-
     def closeStdout(self):
         pass
 
-
     def closeStderr(self):
         pass
 
-
     def doRead(self):
         """
         Called when my standard output stream is ready for reading.
         """
         return fdesc.readFromFD(
-            self.fd,
-            lambda data: self.proto.childDataReceived(1, data))
-
+            self.fd, lambda data: self.proto.childDataReceived(1, data)
+        )
 
     def fileno(self):
         """
@@ -1124,7 +1094,6 @@ class PTYProcess(abstract.FileDescriptor, _BaseProcess):
         """
         return self.fd
 
-
     def maybeCallProcessEnded(self):
         # two things must happen before we call the ProcessProtocol's
         # processEnded method. 1: the child process must die and be reaped
@@ -1135,7 +1104,6 @@ class PTYProcess(abstract.FileDescriptor, _BaseProcess):
         if self.lostProcess == 2:
             _BaseProcess.maybeCallProcessEnded(self)
 
-
     def connectionLost(self, reason):
         """
         I call this to clean up when one or all of my connections has died.
@@ -1145,9 +1113,16 @@ class PTYProcess(abstract.FileDescriptor, _BaseProcess):
         self.lostProcess += 1
         self.maybeCallProcessEnded()
 
-
     def writeSomeData(self, data):
         """
         Write some data to the open process.
         """
         return fdesc.writeToFD(self.fd, data)
+
+    def closeChildFD(self, descriptor):
+        # IProcessTransport
+        raise NotImplementedError()
+
+    def writeToChild(self, childFD, data):
+        # IProcessTransport
+        raise NotImplementedError()
